@@ -1,21 +1,21 @@
 ## ----setting,include=FALSE----------------------------------------------------
-set.seed(1) 
 library(knitr)
 knit_hooks$set(pars = function(before, options, envir) {
     if (before) graphics::par(options$pars)
 })
 opts_chunk$set(message=FALSE, warning=FALSE, tidy=FALSE,
-               fig.path='SPDEhowto-figs/SPDEhowto-')
+               fig.path='figures/SPDEhowto/')
 library(lattice);   library(gridExtra);  library(INLA);  library(plyr) 
 set.seed(123)
 inla.setOption(num.threads="1:1")
 inla.setOption(smtp="taucs")
+if (file.exists("myinit.R")) source("myinit.R")
 lcall <- inla.getOption('inla.call')
 
 ## ----locations,tidy=FALSE-----------------------------------------------------
 n <- 200; coo <- matrix(runif(2*n), n) 
 s2u <- .5; k <- 10; r <- 2/k ## RF params.
-R <- s2u*exp(-k*as.matrix(dist(coo))) 
+R <- s2u*exp(-k*as.matrix(stats::dist(coo))) 
 
 ## ----rmvnorm,tidy=FALSE-------------------------------------------------------
 u <- drop(rnorm(n)%*%chol(R)) 
@@ -53,6 +53,7 @@ pcprec <- list(hyper=list(theta=list(
 mf <- y ~ 0 + b0 + x + f(idx.u, model=spde) 
 res <- inla(mf, control.family=pcprec,
  data=inla.stack.data(stk.e), ## data 
+ control.compute=list(return.marginals.predictor=TRUE),
  control.predictor=list(compute=TRUE, 
   A=inla.stack.A(stk.e)))# full projector
 
@@ -100,6 +101,7 @@ stk.pred <- inla.stack(tag='pred', A=list(Ap, 1), data=list(y=NA), ## response a
   effects=list(idx.u=1:spde$n.spde, data.frame(x=x0, b0=1))) ## all idx.u
 stk.full <- inla.stack(stk.e, stk.pred) ## join the data and prediction scenario
 p.res <- inla(mf, data=inla.stack.data(stk.full), ## supply the full data 
+  control.compute=list(return.marginals.predictor=TRUE),
   control.predictor=list(compute=TRUE, A=inla.stack.A(stk.full)), ## full 
   control.mode=list(theta=res$mode$theta, restart=FALSE))## use mode already found
 
@@ -109,7 +111,7 @@ round(p.res$summary.fitted.val[pred.ind,], 4)
 
 ## ----ppred, tidy=FALSE, fig.width=9.9, fig.height=3.5, out.width='0.99\\textwidth', out.height='0.35\\textwidth', fig.pos='h', fig.keep='last'----
 ypost <- p.res$marginals.fitted.values[pred.ind]
-names(ypost) <- paste('y', seq_along(ypost), sep='_');     library(plyr) 
+names(ypost) <- paste('y', seq_along(ypost), sep='_');   
 xyplot(y~x | .id, ldply(ypost), panel='llines', xlab='y', ylab='Density')
 
 ## ----echo=FALSE--------------------------
